plone.app.event.ical.importer — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.ical.importer

class `plone.app.event.ical.importer.` `IcalendarImportSettings`(context)

  Annotation Adapter for IIcalendarImportSettings.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »